@@ -25,6 +25,7 @@ from typist import PathLike
 import yaml
 
 from . import xdg
+from ._config_file import ConfigFile, YAMLConfigFile
 
 
 Config_T = TypeVar("Config_T", bound="AbstractConfig")
@@ -53,17 +54,18 @@ class AbstractConfig(Protocol[co_Config_T]):
 class Config(BaseSettings):
     """Default CLI arguments / app configuration."""
 
-    config_file: Optional[Path] = None
+    config_file: Optional[ConfigFile] = None
     logs: List[Log] = []
     verbose: int = 0
 
     class Config:
         """Pydantic BaseSettings Configuration.
 
-        NOTE: It is an unfortunate coincidence that this class must be named
-          the same as its parent. This is a pydantic convention, but we (clack
-          library maintainers) refuse to give up on the 'Config' / '*Config'
-          naming scheme.
+        NOTE:
+            It is an unfortunate coincidence that this class must be named the
+            same as its parent. This is a pydantic convention, but we (clack
+            library maintainers) refuse to give up on the 'Config' naming
+            scheme.
         """
 
         # Raise an Exception if anyone tries to modify the configuration
@@ -87,11 +89,13 @@ class Config(BaseSettings):
             return (
                 init_settings,
                 env_settings,
-                _config_settings_factory(),
+                _config_settings_factory(YAMLConfigFile),
             )
 
 
-def _config_settings_factory() -> _SettingsSource:
+def _config_settings_factory(
+    config_file_type: Type[ConfigFile],
+) -> _SettingsSource:
     """Configuration Settings Factory Function
 
     Factory function that returns a pydantic.BaseSettings source callable that
@@ -106,12 +110,13 @@ def _config_settings_factory() -> _SettingsSource:
         configuration file in this group that exists on disk (if any do).
         """
 
-        def __init__(self, config_paths: List[Path]):
+        def __init__(self, config_paths: List[Path], *, set_config_file: bool):
             self.config_paths = config_paths
+            self.set_config_file = set_config_file
 
         @classmethod
         def from_path_lists(
-            cls, *path_like_lists: List[PathLike]
+            cls, *path_like_lists: List[PathLike], set_config_file: bool = True
         ) -> "MutexConfigGroup":
             """MutexConfigGroup class constructor.
 
@@ -122,7 +127,7 @@ def _config_settings_factory() -> _SettingsSource:
             for path_like_list in path_like_lists:
                 for path_like in path_like_list:
                     flat_path_list.append(Path(path_like))
-            return cls(flat_path_list)
+            return cls(flat_path_list, set_config_file=set_config_file)
 
         def populate_config_map(
             self, mut_config_map: MutableMapping[str, Any]
@@ -131,12 +136,18 @@ def _config_settings_factory() -> _SettingsSource:
 
             Set configuration options (by adding keys to the ``mut_config_map``
             mapping) using (at most) one of the config files corresponding with
-            the ``mgroup`` MutexConfigGroup.
+            this MutexConfigGroup.
             """
             for config_path in self.config_paths:
                 if config_path.is_file():
                     yaml_dict = yaml.safe_load(config_path.read_bytes())
                     mut_config_map.update(yaml_dict)
+
+                    if self.set_config_file:
+                        mut_config_map["config_file"] = config_file_type(
+                            config_path
+                        )
+
                     break
 
     def all_yamls(name: PathLike) -> List[PathLike]:
@@ -154,15 +165,16 @@ def _config_settings_factory() -> _SettingsSource:
         config_file = dyn.get_config_file()
 
         if config_file is None:
-            return config_settings_no_config_file(app_name)
+            return config_settings_from_app_name(app_name)
         else:
-            return config_settings_with_config_file(config_file)
+            return config_settings_from_config_file(config_file)
 
-    def config_settings_no_config_file(app_name: str) -> Dict[str, Any]:
-        """The pydantic.BaseSettings source callable that we will return.
+    def config_settings_from_app_name(app_name: str) -> Dict[str, Any]:
+        """Load settings from multiple configuration files based on `app_name`.
 
-        NOTE: This function is only used when a user has NOT specified an
-          explicit config file location (e.g. via --config=foo.yml).
+        NOTE:
+            This function is only used when a user has NOT specified an
+            explicit config file location (e.g. via --config=foo.yml).
         """
         ##### Helper variables used by MutexConfigGroup objects...
         app_path = Path(app_name)
@@ -175,10 +187,15 @@ def _config_settings_factory() -> _SettingsSource:
         ##### MutexConfigGroup variable definitions...
         # user config files used by ALL clack apps
         #
+        # Note that we do NOT set the Config.config_file setting if the only
+        # configuration file found is used by all apps (i.e. belongs to the
+        # following MutexConfigGroup).
+        #
         # e.g. ~/.config/clack/global.yml OR ~/.config/clack/apps/all.yml...
         user_group_for_all_apps = MutexConfigGroup.from_path_lists(
             all_yamls(clack_xdg_dir / "global"),
             all_yamls(clack_apps_dir / "all"),
+            set_config_file=False,
         )
 
         # app-specific user config files
@@ -218,11 +235,12 @@ def _config_settings_factory() -> _SettingsSource:
 
         return result
 
-    def config_settings_with_config_file(config_file: Path) -> Dict[str, Any]:
-        """The pydantic.BaseSettings source callable that we will return.
+    def config_settings_from_config_file(config_file: Path) -> Dict[str, Any]:
+        """Load settings from a single configuration file.
 
-        NOTE: This function is only used when a user has specified an
-          explicit config file location (e.g. via --config=foo.yml).
+        NOTE:
+            This function is only used when a user has specified an explicit
+            config file location (e.g. via --config=foo.yml).
         """
         result: Dict[str, Any] = {}
         single_file_group = MutexConfigGroup.from_path_lists([config_file])
